==> haskell-data-serializer-0.3.5-273-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-data-serializer.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 data-serializer
version:              0.3.5
visibility:           public
id:                   data-serializer-0.3.5-BJvLNYP4s6kKtFm2J4tWNq
key:                  data-serializer-0.3.5-BJvLNYP4s6kKtFm2J4tWNq
license:              BSD-3-Clause
copyright:            2016 Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
maintainer:           Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
author:               Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
stability:            experimental
homepage:             https://github.com/mvv/data-serializer
synopsis:             Common API for serialization libraries
description:
    This package provides a common API for serialization libraries like
    <http://hackage.haskell.org/package/binary binary> and
    <http://hackage.haskell.org/package/cereal cereal>.

category:             Data
abi:                  c6ca39c40c63e1c8c9f12de8dd6481eb
exposed:              True
exposed-modules:      Data.Deserializer Data.Serializer
import-dirs:          /usr/lib/ghc-9.4.8/site-local/data-serializer-0.3.5
library-dirs:         /usr/lib/ghc-9.4.8/site-local/data-serializer-0.3.5
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/data-serializer-0.3.5
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-data-serializer
hs-libraries:         HSdata-serializer-0.3.5-BJvLNYP4s6kKtFm2J4tWNq
depends:
    base-4.17.2.1 binary-0.8.9.1 bytestring-0.11.5.3
    cereal-0.5.8.3-H9MXf6i1TMkEAfnsx4oYbT
    data-endian-0.1.1-7icaZ25RZK5C1z9LOhGoDG
    parsers-0.12.12-6PROTB9MCEOF2XC4sNQYpQ
    split-0.2.5-KlKHd5o1KWaBkefamTdKTk

haddock-interfaces:
    /usr/share/doc/haskell-data-serializer/html/data-serializer.haddock

haddock-html:         /usr/share/doc/haskell-data-serializer/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-data-serializer-0.3.5-274-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-data-serializer.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 data-serializer
version:              0.3.5
visibility:           public
id:                   data-serializer-0.3.5-7HH7Oxq2rzgJNRRi6uAwMV
key:                  data-serializer-0.3.5-7HH7Oxq2rzgJNRRi6uAwMV
license:              BSD-3-Clause
copyright:            2016 Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
maintainer:           Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
author:               Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
stability:            experimental
homepage:             https://github.com/mvv/data-serializer
synopsis:             Common API for serialization libraries
description:
    This package provides a common API for serialization libraries like
    <http://hackage.haskell.org/package/binary binary> and
    <http://hackage.haskell.org/package/cereal cereal>.

category:             Data
abi:                  74dc210379289e8fc336640ec51ebe13
exposed:              True
exposed-modules:      Data.Deserializer Data.Serializer
import-dirs:          /usr/lib/ghc-9.4.8/site-local/data-serializer-0.3.5
library-dirs:         /usr/lib/ghc-9.4.8/site-local/data-serializer-0.3.5
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/data-serializer-0.3.5
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-data-serializer
hs-libraries:         HSdata-serializer-0.3.5-7HH7Oxq2rzgJNRRi6uAwMV
depends:
    base-4.17.2.1 binary-0.8.9.1 bytestring-0.11.5.3
    cereal-0.5.8.3-H9MXf6i1TMkEAfnsx4oYbT
    data-endian-0.1.1-7icaZ25RZK5C1z9LOhGoDG
    parsers-0.12.12-56g1Nx5LuKy21C9ziCb1ow
    split-0.2.5-9yRmZJdLmWeEyOIWbrT71c

haddock-interfaces:
    /usr/share/doc/haskell-data-serializer/html/data-serializer.haddock

haddock-html:         /usr/share/doc/haskell-data-serializer/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
